cheese r599 - in trunk: . src



Author: dgsiegel
Date: Mon Mar 17 22:12:00 2008
New Revision: 599
URL: http://svn.gnome.org/viewvc/cheese?rev=599&view=rev

Log:
set the max waiting time for detecting a camera to 10 seconds, fixes bug #520394


Modified:
   trunk/ChangeLog
   trunk/src/cheese-webcam.c

Modified: trunk/src/cheese-webcam.c
==============================================================================
--- trunk/src/cheese-webcam.c	(original)
+++ trunk/src/cheese-webcam.c	Mon Mar 17 22:12:00 2008
@@ -483,9 +483,9 @@
     pipeline = gst_parse_launch (pipeline_desc, &err);
     if ((pipeline != NULL) && (err == NULL))
     {
       /* Start the pipeline and wait for max. 3 seconds for it to start up */
       gst_element_set_state (pipeline, GST_STATE_PLAYING);
-      ret = gst_element_get_state (pipeline, NULL, NULL, 3 * GST_SECOND);
+      ret = gst_element_get_state (pipeline, NULL, NULL, 10 * GST_SECOND);
 
       /* Check if any error messages were posted on the bus */
       bus = gst_element_get_bus (pipeline);
@@ -483,9 +483,9 @@
     if ((pipeline != NULL) && (err == NULL))
     {
-      /* Start the pipeline and wait for max. 3 seconds for it to start up */
+      /* Start the pipeline and wait for max. 10 seconds for it to start up */
       gst_element_set_state (pipeline, GST_STATE_PLAYING);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]